> **Announcement:**
With Ensenso SDK version 3.3 we stop the maintenance of our
[GitHub repository](https://github.com/ensenso/nxlib-python-interface), since
our SDK now includes a corresponding Python interface package. The Ensenso SDK
can be downloaded [here](https://www.ensenso.com/download).

We will continue to provide the package on PyPI, however, with a few changes:
* The package is from now on named [nxlib](https://pypi.org/project/nxlib/)
* For each new SDK release there will be a corresponding package with the same
  version number as the SDK
* We will also publish the package under the old name
  [ensenso_nxlib](https://pypi.org/project/ensenso_nxlib) (for those who do not
  want to or cannot change their dependency list)

Check our [manual](https://www.ensenso.com/python-api) for installation
guidelines and a detailed description including some examples to get you
started.
